__name__ = 'translate-it'
__version__ = '0.2.0'
__description__ = 'translate it for me.'
__license__ = 'Apache 2.0'
__author__ = 'wen'
__author_email__ = 'w_angzhiwen@163.com'
__url__ = 'https://github.com/suadminwen/translate'
